from setuptools import setup, find_packages

setup(
    name="django_dmf",
    version="0.0.5",
    packages=find_packages(),
    include_package_data=True,
    license_files=["LICENSE"],
    license="MIT",
    description="A Version Controlled Fully Managed Data Migration Framework for Django",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/shivamAthb/django_dmf",
    author="Shivam Sharma",
    author_email="shivam.sharma@helixbeat.com",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Framework :: Django :: 3.2",
        "Framework :: Django :: 4.0",
        "Framework :: Django :: 4.1",
        "Framework :: Django :: 4.2",
        "Framework :: Django :: 5.0",
        "Framework :: Django :: 5.1",
        "Framework :: Django :: 5.2",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Topic :: Software Development :: Libraries",
    ],
    install_requires=["Django>=3.2", 'json-log-formatter'],
    python_requires=">=3.7",
)
