# Generated by Django 5.2.1 on 2025-06-21 15:01

import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="DataMigrationExecution",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("created_on", models.DateTimeField(auto_now_add=True)),
                ("updated_on", models.DateTimeField(auto_now=True)),
                ("task", models.CharField(max_length=500)),
                ("execution_version", models.IntegerField()),
                (
                    "status",
                    models.CharField(
                        choices=[
                            ("IN_PROGRESS", "IN_PROGRESS"),
                            ("FAILED", "FAILED"),
                            ("COMPLETED", "COMPLETED"),
                        ],
                        default="IN_PROGRESS",
                        max_length=100,
                    ),
                ),
            ],
            options={
                "unique_together": {("task", "execution_version")},
            },
        ),
    ]
